@@ -132,8 +132,7 @@ impl TransactionStatusService {
                         let post_token_balances = Some(post_token_balances);
                         let rewards = Some(
                             rent_debits
-                                .0
-                                .into_iter()
+                                .into_unordered_rewards_iter()
                                 .map(|(pubkey, reward_info)| Reward {
                                     pubkey: pubkey.to_string(),
                                     lamports: reward_info.lamports,
